#!/bin/dash
#----------------------------------------------------------------------------#
# Xymon client main script.                                                  #
#                                                                            #
# This invokes the OS-specific script to build a client message, and sends   #
# if off to the Xymon server.                                                #
#                                                                            #
# Copyright (C) 2005-2011 Henrik Storner <henrik@hswn.dk>                    #
#                                                                            #
# This program is released under the GNU General Public License (GPL),       #
# version 2. See the file "COPYING" for details.                             #
#                                                                            #
#----------------------------------------------------------------------------#
#
# $Id: xymonclient.sh 7878 2016-01-26 05:21:46Z jccleaver $

# Must make sure the commands return standard (english) texts.
LANG=C
LC_ALL=C
LC_MESSAGES=C
export LANG LC_ALL LC_MESSAGES

if test $# -ge 1; then
	if test "$1" = "--local"; then
		LOCALMODE="yes"
	fi
	shift
fi

if test "$LOCALMODE" = "yes" -a ! -x /usr/libexec/xymon/xymond_client; then
	echo "ERROR: Local mode (--local) disabled because /usr/libexec/xymon/xymond_client not found; you may need to install a xymon-client-local package" >&2
	LOCALMODE="no"
fi

if test "$XYMONOSSCRIPT" = ""; then
	XYMONOSSCRIPT="xymonclient-`uname -s | tr '[ABCDEFGHIJKLMNOPQRSTUVWXYZ/]' '[abcdefghijklmnopqrstuvwxyz_]'`.sh"
fi

# Overrides for xymoncmd from /etc/sysconfig/xymon-client
if test "$CLIENTOS" != ""; then
	SERVEROSTYPE="$CLIENTOS"
fi
if test "$CLIENTHOSTNAME" != ""; then
	MACHINEDOTS="$CLIENTHOSTNAME"
	MACHINE="`echo \"$CLIENTHOSTNAME\" | tr '.' ','`"
fi

MSGFILE="$XYMONTMP/msg.$MACHINEDOTS.txt"
MSGTMPFILE="$MSGFILE.$$"
if test "$LOCALMODE" = "yes"; then
    if test -z "$LOCAL_CLIENTCONFIG"; then
	LOCAL_CLIENTCONFIG="/etc/xymon-client/localclient.cfg"
    fi
    if test -z "$LOCAL_LOGFETCHCFG"; then
	LOCAL_LOGFETCHCFG="/etc/xymon-client/logfetch.cfg"
    fi

    # If not present, fall back to dynamic logfetch location below
    if test -f "$LOCAL_LOGFETCHCFG"; then
	LOGFETCHCFG="$LOCAL_LOGFETCHCFG"
    fi
fi

if test -z "$LOGFETCHCFG"; then
	LOGFETCHCFG=$XYMONTMP/logfetch.$MACHINEDOTS.cfg
fi
if test -z "$LOGFETCHSTATUS"; then
	LOGFETCHSTATUS=$XYMONCLIENTLOGS/logfetch.$MACHINEDOTS.status
fi

export LOGFETCHCFG LOGFETCHSTATUS

rm -f $MSGTMPFILE
touch $MSGTMPFILE


CLIENTVERSION="Xymon version 4.3.25-1.fc22"

if test "$LOCALMODE" = "yes"; then
	echo "@@client#1|1|127.0.0.1|$MACHINEDOTS|$SERVEROSTYPE" >> $MSGTMPFILE
fi

if test "$SUBMITMODE" = "yes"; then
	echo "clientsubmit $MACHINE.$SERVEROSTYPE $CONFIGCLASS"  >>  $MSGTMPFILE
elif test "$STATUSMODE" = "yes"; then
	echo "status $MACHINE.xymonclient client $SERVEROSTYPE $CONFIGCLASS"  >>  $MSGTMPFILE
else
	echo "client $MACHINE.$SERVEROSTYPE $CONFIGCLASS"  >>  $MSGTMPFILE
fi

/usr/libexec/xymon-client/$XYMONOSSCRIPT >> $MSGTMPFILE
# logfiles
if test -f $LOGFETCHCFG
then
    /usr/libexec/xymon-client/logfetch $LOGFETCHOPTS $LOGFETCHCFG $LOGFETCHSTATUS >>$MSGTMPFILE
fi
# Client version
echo "[clientversion]"  >>$MSGTMPFILE
echo "$CLIENTVERSION"   >> $MSGTMPFILE

# See if there are any individual client sections
if test -d /usr/share/xymon-client/sections; then
	for MODULE in `ls /usr/share/xymon-client/sections/* 2>/dev/null | grep -v -e \.rpm -e \.dpkg`
	do
		if test -x $MODULE -a -f $MODULE
		then
			echo "[`basename $MODULE`]" >>$MSGTMPFILE
			$MODULE >>$MSGTMPFILE
		fi
	done
fi

# See if there are any local add-ons (must do this before checking the clock)
if test -d /usr/local/share/xymon-client -o -d /usr/share/xymon-client/local; then
	for MODULE in /usr/local/share/xymon-client/* /usr/share/xymon-client/local/*
	do
		if test -x $MODULE
		then
			echo "[local:`basename $MODULE`]" >>$MSGTMPFILE
			$MODULE >>$MSGTMPFILE
		fi
	done
fi

# System clock
echo "[clock]"          >> $MSGTMPFILE
/usr/libexec/xymon-client/logfetch --clock >> $MSGTMPFILE

if test "$LOCALMODE" = "yes"; then
	echo "@@" >> $MSGTMPFILE
	/usr/libexec/xymon/xymond_client --local $LOCAL_CLIENTOPTS --config=$LOCAL_CLIENTCONFIG <$MSGTMPFILE
elif test "$SUBMITMODE" = "yes" -o "$STATUSMODE" = "yes"; then
	# Send to any/all at once; there won't be output (except for errors)
	for THISSRV in $XYMSERVERS; do
		$XYMON $THISSRV "@" < $MSGTMPFILE &
	done
	sleep 4
else
	$XYMON $XYMSRV "@" < $MSGTMPFILE >$LOGFETCHCFG.tmp
	if test -f $LOGFETCHCFG.tmp
	then
		if test -s $LOGFETCHCFG.tmp
		then
			mv $LOGFETCHCFG.tmp $LOGFETCHCFG
		else
			rm -f $LOGFETCHCFG.tmp
		fi
	fi
fi

# Save the latest file for debugging.
rm -f $MSGFILE
mv $MSGTMPFILE $MSGFILE

exit 0

